<?php

namespace Bixo\Viewing\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Bixo\Viewing\Http\Requests\ViewingRequest;
use Bixo\Viewing\Models\Viewing;

/**
 * Admin web controller class.
 */
class ViewingWorkflowController extends BaseController
{

    /**
     * Workflow controller function for viewing.
     *
     * @param Model   $viewing
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ViewingRequest $request, Viewing $viewing, $step)
    {

        try {

            $viewing->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('viewing::viewing.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/viewing/viewing/' . $viewing->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/viewing/viewing/' . $viewing->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for viewing.
     *
     * @param Model   $viewing
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Viewing $viewing, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $viewing->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('viewing::viewing.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('viewing::admin.viewing.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('viewing::admin.viewing.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('viewing::admin.viewing.message', $data)->render();

        }

    }
}
