<?php

namespace Bixo\Viewing\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Viewing\Models\Viewing;

class ViewingPolicy
{

    /**
     * Determine if the given user can view the viewing.
     *
     * @param UserPolicy $user
     * @param Viewing $viewing
     *
     * @return bool
     */
    public function view(UserPolicy $user, Viewing $viewing)
    {
        if ($user->canDo('viewing.viewing.view') && $user->isAdmin()) {
            return true;
        }

        return $viewing->user_id == user_id() && $viewing->user_type == user_type();
    }

    /**
     * Determine if the given user can create a viewing.
     *
     * @param UserPolicy $user
     * @param Viewing $viewing
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('viewing.viewing.create');
    }

    /**
     * Determine if the given user can update the given viewing.
     *
     * @param UserPolicy $user
     * @param Viewing $viewing
     *
     * @return bool
     */
    public function update(UserPolicy $user, Viewing $viewing)
    {
        if ($user->canDo('viewing.viewing.edit') && $user->isAdmin()) {
            return true;
        }

        return $viewing->user_id == user_id() && $viewing->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given viewing.
     *
     * @param UserPolicy $user
     * @param Viewing $viewing
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Viewing $viewing)
    {
        return $viewing->user_id == user_id() && $viewing->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given viewing.
     *
     * @param UserPolicy $user
     * @param Viewing $viewing
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Viewing $viewing)
    {
        if ($user->canDo('viewing.viewing.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given viewing.
     *
     * @param UserPolicy $user
     * @param Viewing $viewing
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Viewing $viewing)
    {
        if ($user->canDo('viewing.viewing.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
