<?php

namespace Bixo\Viewing\Providers;

use Illuminate\Support\ServiceProvider;

class ViewingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'viewing');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'viewing');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerViewing();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerViewing()
    {
        $this->app->bind('viewing', function($app) {
            return new Viewing($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Viewing', 'Lavalite\Viewing\Facades\Viewing');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.viewing', function ($app) {
            return $this->app->make('Bixo\Viewing\Viewing');
        });

                // Bind Viewing to repository
        $this->app->bind(
            'Bixo\Viewing\Interfaces\ViewingRepositoryInterface',
            \Bixo\Viewing\Repositories\Eloquent\ViewingRepository::class
        );

        $this->app->register(\Bixo\Viewing\Providers\AuthServiceProvider::class);
                $this->app->register(\Bixo\Viewing\Providers\EventServiceProvider::class);
        
        $this->app->register(\Bixo\Viewing\Providers\RouteServiceProvider::class);
                // $this->app->register(\Bixo\Viewing\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and viewing's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.viewing'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeViewing::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.viewing'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/viewing.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/viewing')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/viewing')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
