<?php

namespace Bixo\Viewing\Workflow;

use Bixo\Viewing\Models\Viewing;
use Validator;

class ViewingValidator
{

    /**
     * Determine if the given viewing is valid for complete status.
     *
     * @param Viewing $viewing
     *
     * @return bool / Validator
     */
    public function complete(Viewing $viewing)
    {
        return Validator::make($viewing->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given viewing is valid for verify status.
     *
     * @param Viewing $viewing
     *
     * @return bool / Validator
     */
    public function verify(Viewing $viewing)
    {
        return Validator::make($viewing->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given viewing is valid for approve status.
     *
     * @param Viewing $viewing
     *
     * @return bool / Validator
     */
    public function approve(Viewing $viewing)
    {
        return Validator::make($viewing->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given viewing is valid for publish status.
     *
     * @param Viewing $viewing
     *
     * @return bool / Validator
     */
    public function publish(Viewing $viewing)
    {
        return Validator::make($viewing->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given viewing is valid for archive status.
     *
     * @param Viewing $viewing
     *
     * @return bool / Validator
     */
    public function archive(Viewing $viewing)
    {
        return Validator::make($viewing->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given viewing is valid for unpublish status.
     *
     * @param Viewing $viewing
     *
     * @return bool / Validator
     */
    public function unpublish(Viewing $viewing)
    {
        return Validator::make($viewing->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
